<?php

/**
 * @var int $page_number
 */

use App\Models\User;
use Itguild\EloquentTable\EloquentDataProvider;
use Itguild\EloquentTable\ListEloquentTable;

$table = new ListEloquentTable(new EloquentDataProvider(User::class, [
    'currentPage' => $page_number,
    'perPage' => 3,
    'params' => ["class" => "table table-bordered", "border" => "2"],
    'baseUrl' => "/admin/user",
    'searchPrefix' => "",
]));

$table->columns([
    'user_photo' => function ($data) {
        return $data ? "<img src='$data' width='150px'>" : "";
    },
    'created_at' => function ($data) {
        if (!$data) {
            return null;
        }

        return (new DateTimeImmutable($data))->format("d-m-Y");
    },
    'updated_at' => function ($data) {
        if (!$data) {
            return null;
        }

        return (new DateTimeImmutable($data))->format("d-m-Y");
    }
]);
$table->beforePrint(function () {
    return (new \App\Widgets\IconBtnCreateWidget(['url' => '/admin/user/create']))->run();
});
//$table->beforePrint(function () {
//    return "<a title='Создать' class='btn btn-success' href='/admin/user/create' style='margin: 3px' ><i class='fa-regular fa-square-plus'></i></a>";
//});
$table->addAction(function($row) {
     return (new \App\Widgets\IconBtnViewWidget(['url' => '/admin/user/view/' . $row['id']]))->run();
});
$table->addAction(function($row) {
    return (new \App\Widgets\IconBtnEditWidget(['url' => '/admin/user/update/' . $row['id']]))->run();
});
$table->addAction(function($row) {
//    return "<a title='Удалить' class='btn btn-danger' href='/admin/user/delete/" . $row['id'] . "' style='margin: 3px' ><i class='fa-regular fa-trash-can'></i></a>";
    return (new \App\Widgets\IconBtnDeleteWidget(['url' => '/admin/user/delete/' . $row['id']]))->run();
});
$table->create();

?>
<x-main>
    <x-slot:title>
        Custom Title
    </x-slot>

    @php
        $table->render();
    @endphp

</x-main>

