<?php

/**
 * @var App\Models\User $user
 */

use App\Widgets\IconBtnDeleteWidget;
use App\Widgets\IconBtnEditWidget;
use App\Widgets\IconBtnListWidget;
use Itguild\EloquentTable\ViewEloquentTable;
use Itguild\EloquentTable\ViewJsonTableEloquentModel;

$table = new ViewEloquentTable(new ViewJsonTableEloquentModel($user, [
    'params' => ["class" => "table table-bordered", "border" => "2"],
    'baseUrl' => "/admin/user",
]));

$table->beforePrint(function () use ($user) {
    $btn = (new IconBtnListWidget(['url' => '/admin/user']))->run();
    $btn .= (new IconBtnEditWidget(['url' => '/admin/user/update/' . $user->id]))->run();
    $btn .= (new IconBtnDeleteWidget(['url' => '/admin/user/delete/' . $user->id]))->run();
    return $btn;
});

$table->rows([
    'user_photo' => function ($data) {
        return $data ? "<img src='$data' width='300px'>" : "";
    },
    'created_at' => function ($data) {
        if (!$data) {
            return null;
        }

        return (new DateTimeImmutable($data))->format("d-m-Y");
    },
    'updated_at' => function ($data) {
        if (!$data) {
            return null;
        }

        return (new DateTimeImmutable($data))->format("d-m-Y");
    }
]);
$table->create();
?>

<x-main>
    <x-slot:title>
        Custom Title
    </x-slot>

    @php
        $table->render();
    @endphp

</x-main>
